@@ -5,7 +5,7 @@ import subprocess
 import sys
 from argparse import Namespace
 from functools import lru_cache
-from typing import Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Tuple
 
 from packaging.version import Version
 
@@ -13,6 +13,8 @@ from ansiblelint.constants import ANSIBLE_MISSING_RC
 
 DEFAULT_KINDS = [
     # Do not sort this list, order matters.
+    {"jinja2": "**/*.j2"},  # jinja2 templates are not always parsable as something else
+    {"jinja2": "**/*.j2.*"},
     {"requirements": "**/meta/requirements.yml"},  # v1 only
     # https://docs.ansible.com/ansible/latest/dev_guide/collections_galaxy_meta.html
     {"galaxy": "**/galaxy.yml"},  # Galaxy collection meta
@@ -40,6 +42,11 @@ BASE_KINDS = [
     # These assignations are only for internal use and are only inspired by
     # MIME/IANA model. Their purpose is to be able to process a file based on
     # it type, including generic processing of text files using the prefix.
+    {
+        "text/jinja2": "**/*.j2"
+    },  # jinja2 templates are not always parsable as something else
+    {"text/jinja2": "**/*.j2.*"},
+    {"text": "**/templates/**/*.*"},  # templates are likely not validable
     {"text/json": "**/*.json"},  # standardized
     {"text/markdown": "**/*.md"},  # https://tools.ietf.org/html/rfc7763
     {"text/rst": "**/*.rst"},  # https://en.wikipedia.org/wiki/ReStructuredText
@@ -77,6 +84,7 @@ options = Namespace(
     extra_vars=None,
     enable_list=[],
     skip_action_validation=True,
+    rules=dict(),  # Placeholder to set and keep configurations for each rule.
 )
 
 # Used to store detected tag deprecations
@@ -86,6 +94,11 @@ used_old_tags: Dict[str, str] = {}
 collection_list: List[str] = []
 
 
+def get_rule_config(rule_id: str) -> Dict[str, Any]:
+    """Get configurations for the rule ``rule_id``."""
+    return options.rules.get(rule_id, dict())
+
+
 @lru_cache()
 def ansible_collections_path() -> str:
     """Return collection path variable for current version of Ansible."""
